@@ -25,17 +25,17 @@ pub(crate) use {
     fragment::Fragment, function::Function, function_context::FunctionContext,
     interrupt_guard::InterruptGuard, interrupt_handler::InterruptHandler, item::Item,
     justfile::Justfile, keyed::Keyed, keyword::Keyword, lexer::Lexer, line::Line, list::List,
-    load_dotenv::load_dotenv, loader::Loader, name::Name, ordinal::Ordinal, output::output,
-    output_error::OutputError, parameter::Parameter, parameter_kind::ParameterKind, parser::Parser,
-    platform::Platform, platform_interface::PlatformInterface, position::Position,
-    positional::Positional, range_ext::RangeExt, recipe::Recipe, recipe_context::RecipeContext,
-    recipe_resolver::RecipeResolver, scope::Scope, search::Search, search_config::SearchConfig,
-    search_error::SearchError, set::Set, setting::Setting, settings::Settings, shebang::Shebang,
-    shell::Shell, show_whitespace::ShowWhitespace, string_kind::StringKind,
-    string_literal::StringLiteral, subcommand::Subcommand, suggestion::Suggestion, table::Table,
-    thunk::Thunk, token::Token, token_kind::TokenKind, unresolved_dependency::UnresolvedDependency,
-    unresolved_recipe::UnresolvedRecipe, use_color::UseColor, variables::Variables,
-    verbosity::Verbosity, warning::Warning,
+    load_dotenv::load_dotenv, loader::Loader, name::Name, namepath::Namepath, ordinal::Ordinal,
+    output::output, output_error::OutputError, parameter::Parameter, parameter_kind::ParameterKind,
+    parser::Parser, platform::Platform, platform_interface::PlatformInterface, position::Position,
+    positional::Positional, ran::Ran, range_ext::RangeExt, recipe::Recipe,
+    recipe_context::RecipeContext, recipe_resolver::RecipeResolver, scope::Scope, search::Search,
+    search_config::SearchConfig, search_error::SearchError, set::Set, setting::Setting,
+    settings::Settings, shebang::Shebang, shell::Shell, show_whitespace::ShowWhitespace,
+    source::Source, string_kind::StringKind, string_literal::StringLiteral, subcommand::Subcommand,
+    suggestion::Suggestion, table::Table, thunk::Thunk, token::Token, token_kind::TokenKind,
+    unresolved_dependency::UnresolvedDependency, unresolved_recipe::UnresolvedRecipe,
+    use_color::UseColor, variables::Variables, verbosity::Verbosity, warning::Warning,
   },
   std::{
     cmp,
@@ -47,6 +47,7 @@ pub(crate) use {
     io::{self, Cursor, Write},
     iter::{self, FromIterator},
     mem,
+    ops::Deref,
     ops::{Index, Range, RangeInclusive},
     path::{self, Path, PathBuf},
     process::{self, Command, ExitStatus, Stdio},
@@ -83,9 +84,9 @@ pub use crate::run::run;
 #[doc(hidden)]
 pub use unindent::unindent;
 
-pub(crate) type CompileResult<'a, T> = Result<T, CompileError<'a>>;
+pub(crate) type CompileResult<'a, T = ()> = Result<T, CompileError<'a>>;
 pub(crate) type ConfigResult<T> = Result<T, ConfigError>;
-pub(crate) type RunResult<'a, T> = Result<T, Error<'a>>;
+pub(crate) type RunResult<'a, T = ()> = Result<T, Error<'a>>;
 pub(crate) type SearchResult<T> = Result<T, SearchError>;
 
 #[cfg(test)]
@@ -149,6 +150,7 @@ mod list;
 mod load_dotenv;
 mod loader;
 mod name;
+mod namepath;
 mod ordinal;
 mod output;
 mod output_error;
@@ -159,6 +161,7 @@ mod platform;
 mod platform_interface;
 mod position;
 mod positional;
+mod ran;
 mod range_ext;
 mod recipe;
 mod recipe_context;
@@ -174,6 +177,7 @@ mod settings;
 mod shebang;
 mod shell;
 mod show_whitespace;
+mod source;
 mod string_kind;
 mod string_literal;
 mod subcommand;
