@@ -33,10 +33,10 @@ fn duplicate_attributes_are_disallowed() {
     .stderr(
       "
       error: Recipe attribute `no-exit-message` first used on line 1 is duplicated on line 2
-       --> justfile:2:2
-        |
-      2 | [no-exit-message]
-        |  ^^^^^^^^^^^^^^^
+       ——▶ justfile:2:2
+        │
+      2 │ [no-exit-message]
+        │  ^^^^^^^^^^^^^^^
       ",
     )
     .status(1)
@@ -72,11 +72,11 @@ fn multiple_attributes_one_line_error_message() {
     )
     .stderr(
       "
-        error: Expected ']' or ',', but found identifier
-         --> justfile:1:17
-          |
-        1 | [macos, windows linux]
-          |                 ^^^^^
+        error: Expected ']', ',', or '(', but found identifier
+         ——▶ justfile:1:17
+          │
+        1 │ [macos, windows linux]
+          │                 ^^^^^
           ",
     )
     .status(1)
@@ -97,12 +97,35 @@ fn multiple_attributes_one_line_duplicate_check() {
     .stderr(
       "
       error: Recipe attribute `linux` first used on line 1 is duplicated on line 2
-       --> justfile:2:2
-        |
-      2 | [linux]
-        |  ^^^^^
+       ——▶ justfile:2:2
+        │
+      2 │ [linux]
+        │  ^^^^^
         ",
     )
     .status(1)
     .run();
 }
+
+#[test]
+fn unexpected_attribute_argument() {
+  Test::new()
+    .justfile(
+      "
+      [private('foo')]
+      foo:
+        exit 1
+    ",
+    )
+    .stderr(
+      "
+        error: Attribute `private` specified with argument but takes no arguments
+         ——▶ justfile:1:2
+          │
+        1 │ [private('foo')]
+          │  ^^^^^^^
+          ",
+    )
+    .status(1)
+    .run();
+}
